// Copyright 2019 github.com. All rights reserved.
// Use of this source code is governed by github.com.

package v1

import (
	"smart-site-management-gateway/param/base"
	"smart-site-management-gateway/pb/v1"
)

type DeviceBindCameraBody struct {
	DeviceId int64 `json:"device_id" form:"device_id"`
	ChannelId int64 `json:"channel_id" form:"channel_id"`
	DeviceCode int32 `json:"device_code" form:"device_code"`
}

type DeviceBindCameraRequest struct {
	base.Header
	DeviceBindCameraBody
}


type DeviceBindCameraResponse struct {
	base.Result
}

type DeviceUnbindCameraBody struct {
	DeviceId int64 `json:"device_id" form:"device_id"`
	ChannelId int64 `json:"channel_id" form:"channel_id"`
	DeviceCode int32 `json:"device_code" form:"device_code"`
}

type DeviceUnbindCameraRequest struct {
	base.Header
	DeviceUnbindCameraBody
}


type DeviceUnbindCameraResponse struct {
	base.Result
}

type DeviceCameraQuery struct {
	DeviceId int64 `form:"device_id"`
}

type DeviceCameraRequest struct {
	base.Header
	DeviceCameraQuery
}


type DeviceCameraResponse struct {
	base.Result
	Data v1.CameraListItem `json:"data"`
}


type CameraListQuery struct {
	VssId int64 `form:"vss_id"`
	Page int32 `form:"page"`
	IsUnused bool `form:"is_unused"`
}
type CameraListRequest struct {
	base.Header
	CameraListQuery
}

type CameraUnusedItem struct {
	// 通道所属视频设备的sn
	VssSn string `protobuf:"bytes,1,opt,name=vss_sn,json=vssSn,proto3" json:"vss_sn"`
	// 摄像头所属视频设备的name
	VssName string `protobuf:"bytes,2,opt,name=vss_name,json=vssName,proto3" json:"vss_name"`
	// 摄像头id
	ChannelId int64 `protobuf:"varint,5,opt,name=channel_id,json=channelId,proto3" json:"channel_id"`
	// 摄像头所属视频设备的id
	VssId int64 `protobuf:"varint,6,opt,name=vss_id,json=vssId,proto3" json:"vss_id"`
	// 摄像头通道号
	ChannelNo            string   `protobuf:"bytes,7,opt,name=channel_no,json=channelNo,proto3" json:"channel_no"`
	ChannelName          string   `protobuf:"bytes,8,opt,name=channel_name,json=channelName,proto3" json:"channel_name"`

}

type CameraUnusedData struct {
	List []CameraUnusedItem `json:"list"`
}

type CameraUnusedListResponse struct {
	base.Result
	Data CameraUnusedData `json:"data"`
}

type CameraListResponse struct {
	base.Result
	Data v1.CameraListReply `json:"data"`
}

type ChannelListQuery struct {
	Sn string `form:"sn"`
	Page int32 `form:"page"`
	ChannelNo string `form:"channel_no"`
	PageSize int32 `form:"page_size"`
}

type ChannelListRequest struct {
	base.Header
	ChannelListQuery
}

type ChannelListResponse struct {
	base.Result
	Data v1.ChannelListReply `json:"data"`
}

type ChannelListUnbindData struct {
	List []*v1.ChannelItem `json:"list"`
}
type ChannelListUnbindResponse struct {
	base.Result
	Data ChannelListUnbindData `json:"data"`
}

type VedioListQuery struct {
	// 审核状态 0 待审核 1 通过 2 未通过
	FilterStatus string `form:"filter_status"`
	ProjectId int64 `form:"project_id"`
	Filter string `form:"filter"`
	Page int32 `form:"page"`
	State int32 `form:"state"`
}

type VedioListRequest struct {
	base.Header
	VedioListQuery
}

type VedioListResponse struct {
	base.Result
	Data v1.VedioListReply `json:"data"`
}

type RealPlayQuery struct {
	ChannelNo string `form:"channel_no"`
}

type RealPlayRequest struct {
	base.Header
	RealPlayQuery
}

type RealPlayResponse struct {
	base.Result
	Data v1.RealPlayReply `json:"data"`
}

type PtzQuery struct {
	ChannelNo string `form:"channel_no"`
	PtzType string `form:"ptz_type"`
	PtzParam int32 `form:"ptz_param"`
}

type PtzRequest struct {
	base.Header
	PtzQuery
}

type PtzResponse struct {
	base.Result
}

type VedioPingQuery struct {
	SessionId string `form:"session_id"`
}

type VedioPingRequest struct {
	base.Header
	VedioPingQuery
}

type VedioPingResponse struct {
	base.Result
	Data v1.VedioPingReply `json:"data"`
}

type ChannelUpdateBody struct {
	Id int64 `form:"id"`
	Name string `form:"name"`
}

type ChannelUpdateRequest struct {
	base.Header
	ChannelUpdateBody
}

type ChannelUpdateResponse struct {
	base.Result
}
