// Copyright 2019 github.com. All rights reserved.
// Use of this source code is governed by github.com.

package v1

import (
	"smart-site-management-gateway/param/base"
	"smart-site-management-gateway/pb/v1"
)

type ProjectInfoItem struct {
	// 字段名称
	Name string `form:"name" json:"name"`
	// 字段值
	Value string `form:"value" json:"value"`
}

type ProjectChangeBody struct {
	List []ProjectInfoItem `form:"list" json:"list"`
}

type ProjectChangeRequest struct {
	base.Header
	ProjectChangeBody
}

type ProjectChangeResponse struct {
	base.Result
}

type ProjectInfoForChangeRequest struct {
	base.Header
}
type ProjectInfoForChangeResponse struct {
	base.Result
	Data v1.ProjectInfoForChangeReply `json:"data"`
}

type ProjectChangeInfoListQuery struct {
	Page int32 `form:"page"`
}

type ProjectChangeInfoListRequest struct {
	base.Header
	ProjectChangeInfoListQuery
}

type ProjectChangeInfoListResponse struct {
	base.Result
	Data v1.ProjectChangeInfoListReply `json:"data"`
}

type DeviceApproveBody struct {
	// 设备id
	Id int64 `form:"id"`
	// true 通过 false 不通过
	Status bool `form:"status"`
	// 审批回复
	Feedback string `form:"feedback"`

	DeviceCode int32 `form:"device_code" json:"device_code"`
}

type DeviceApproveRequest struct {
	base.Header
	DeviceApproveBody
}

type DeviceApproveResponse struct {
	base.Result
}

type DeviceListQuery struct {
	// 审核状态 0 待审核 1 通过 2 未通过
	Status   int    `form:"status"`
	Filter   string `form:"filter"`
	Page     int32  `form:"page"`
	PageSize int64  `form:"page_size"`
	State int32 `form:"state"`
}

type DeviceListRequest struct {
	base.Header
	DeviceListQuery
}

type DeviceListResponse struct {
	base.Result
	Data v1.DeviceListReply `json:"data"`
}

type ProjectInfoRequest struct {
	base.Header
}

type ProjectInfoResponse struct {
	base.Result
	Data v1.ProjectInfoReply `json:"data"`
}

type ProjectDeviceStatisticsRequest struct {
	base.Header
}

type ProjectDeviceStatisticsResponse struct {
	base.Result
	Data v1.ProjectDeviceStatisticsReply `json:"data"`
}

type ProjectProgressRequest struct {
	base.Header
}

type ProjectProgressResponse struct {
	base.Result
	Data v1.ProjectProgressReply `json:"data"`
}

type ProjectProgressAddBody struct {
	Name            string `form:"name"`
	ExpectStartTime int64  `form:"expect_start_time"`
	ExpectEndTime   int64  `form:"expect_end_time"`
}

type ProjectProgressAddRequest struct {
	base.Header
	ProjectProgressAddBody
}

type ProjectProgressAddResponse struct {
	base.Result
	Data v1.ProjectProgressAddReply `json:"data"`
}

type ProjectProgressDelPath struct {
	Id int64 `uri:"id"`
}

type ProjectProgressDelRequest struct {
	base.Header
	ProjectProgressDelPath
}

type ProjectProgressDelResponse struct {
	base.Result
}

type ProjectProgressSetBody struct {
	Id               int64  `form:"id"`
	Image            string `form:"image"`
	RealityStartTime int64  `form:"reality_start_time" json:"reality_start_time"`
	RealityEndTime   int64  `form:"reality_end_time" json:"reality_end_time"`
}

type ProjectProgressSetRequest struct {
	base.Header
	ProjectProgressSetBody
}

type ProjectProgressSetResponse struct {
	base.Result
}

type DeviceVideoChannelQuery struct {
	Sn string `form:"sn"`
}

type DeviceVideoChannelRequest struct {
	base.Header
	DeviceVideoChannelQuery
}

type DeviceVideoChannelResponse struct {
	base.Result
	Data v1.DeviceVideoChannelReply `json:"data"`
}

type ProjectSetPicBody struct {
	// 0 平面图 1 效果图
	PicType int32    `form:"pic_type"`
	PicUrl  []string `form:"pic_url"`
}

type ProjectSetPicRequest struct {
	base.Header
	ProjectSetPicBody
}

type ProjectSetPicResponse struct {
	base.Result
}

type ProjectUpdateBody struct {
	Name      string `form:"name"`
	ShortName string `form:"short_name"`
	Location  string `form:"location"`
}

type ProjectUpdateRequest struct {
	base.Header
	ProjectUpdateBody
}

type ProjectUpdateResponse struct {
	base.Result
}

type ProjectCorpAddBody struct {
	// 单位名称
	Name string `form:"name" json:"name"`
	// 单位所在行政区域代码
	AreaCode string `form:"area_code" json:"area_code"`
	// 单位社会信用码
	SocialCode string `form:"social_code" json:"social_code"`
	// 注册日期
	RegisterDate int64 `form:"register_date" json:"register_date"`
	// 参建类型
	CorpType uint32 `form:"corp_type" json:"corp_type"`
}

type ProjectCorpAddRequest struct {
	base.Header
	ProjectCorpAddBody
}

type ProjectCorpAddResponse struct {
	base.Result
	Data v1.ProjectCorpAddReply `json:"data"`
}

type ProjectCorpUpdateBody struct {
	Id int64 `form:"id" json:"id"`
	// 单位名称
	Name string `form:"name" json:"name"`
	// 单位所在行政区域代码
	AreaCode string `form:"area_code" json:"area_code"`
	// 单位社会信用码
	SocialCode string `form:"social_code" json:"social_code"`
	// 注册日期
	RegisterDate int64 `form:"register_date" json:"register_date"`
	// 参建类型
	CorpType uint32 `form:"corp_type" json:"corp_type"`
}

type ProjectCorpUpdateRequest struct {
	base.Header
	ProjectCorpUpdateBody
}

type ProjectCorpUpdateResponse struct {
	base.Result
}

type ProjectCorpDelPath struct {
	Id int64 `uri:"id"`
}
type ProjectCorpDelRequest struct {
	base.Header
	ProjectCorpDelPath
}

type ProjectCorpDelResponse struct {
	base.Result
}

type ProjectCorpListRequest struct {
	base.Header
}

type ProjectCorpListResponse struct {
	base.Result
	Data v1.ProjectCorpListReply `json:"data"`
}

type ProjectPMAddBody struct {

	//
	CorpId int64 `form:"corp_id" json:"corp_id"`

	// 人员类型
	PType uint32 `form:"p_type" json:"p_type"`
	// 姓名
	Name string `form:"name" json:"name"`
	// 证件类型
	CertType uint32 `form:"cert_type" json:"cert_type"`
	// 证件号
	CertNum string `form:"cert_num" json:"cert_num"`
	// 电话号
	Phone string `form:"phone" json:"phone"`
}

type ProjectPMAddRequest struct {
	base.Header
	ProjectPMAddBody
}

type ProjectPMAddResponse struct {
	base.Result
	Data v1.ProjectPMAddReply `json:"data"`
}

type ProjectPMUpdateBody struct {
	Id int64 `form:"id" json:"id"`

	// 单位社会信用码
	CorpId int64 `form:"corp_id" json:"corp_id"`

	// 人员类型
	PType uint32 `form:"p_type" json:"p_type"`
	// 姓名
	Name string `form:"name" json:"name"`
	// 证件类型
	CertType uint32 `form:"cert_type" json:"cert_type"`
	// 证件号
	CertNum string `form:"cert_num" json:"cert_num"`
	// 电话号
	Phone string `form:"phone" json:"phone"`
}

type ProjectPMUpdateRequest struct {
	base.Header
	ProjectPMUpdateBody
}

type ProjectPMUpdateResponse struct {
	base.Result
}

type ProjectPMDelPath struct {
	Id int64 `uri:"id"`
}
type ProjectPMDelRequest struct {
	base.Header
	ProjectPMDelPath
}

type ProjectPMDelResponse struct {
	base.Result
}

type ProjectPMListQuery struct {
	Page int32 `form:"page"`
	PageSize int32 `form:"page_size"`
	CorpId int64 `form:"corp_id" json:"corp_id"`
	Filter string `form:"filter"`
}

type ProjectPMListRequest struct {
	base.Header
	ProjectPMListQuery
}

type ProjectPMListResponse struct {
	base.Result
	Data v1.ProjectPMListReply `json:"data"`
}

type AreaCodeListRequest struct {

}

type AreaCodeListResponse struct {
	base.Result
	Data v1.AreaCodeListReply `json:"data"`
}

